@@ -107,6 +107,7 @@ protected:
     FXuint			matchmode;				// File wildcard match mode
     FXuint			counter;				// Refresh counter
 	FXString		trashlocation;          // Location of the trash directory
+	FXWindow		*focuswindow;			// Window used to test focus
 protected:
     //DirList();
     DirList()
@@ -191,7 +192,7 @@ public:
 public:
 
     // Construct a directory list
-    DirList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    DirList(FXWindow *focuswin,FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
     // Create server-side resources
     virtual void create();
@@ -260,7 +261,7 @@ public:
     void showFiles(FXbool showing);
 
     // Return TRUE if showing hidden files and directories
-    FXbool showHiddenFiles() const;
+    FXbool shownHiddenFiles() const;
 
     // Show or hide hidden files and directories
     void showHiddenFiles(FXbool showing);
