@@ -20,6 +20,7 @@ protected:
     FXLabel	*status;
 	FXString homelocation;
 	FXString trashlocation;
+	FXString startlocation;
 	FXDragType urilistType;        // Standard uri-list type
 	FXDragType xfelistType;        // Xfe, Gnome and XFCE list type
 	FXDragType kdelistType;        // KDE list type
@@ -29,9 +30,12 @@ protected:
 	ArchInputDialog* archdialog;
 	BrowseInputDialog* operationdialog;
 	FXbool paste;
+	FXWindow* focuswindow;
+	FXbool ctrlflag;			// Flag to select the right click control menu
 
 public:
-DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0),FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+DirPanel(FXWindow *owner,FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listforecolor=FXRGB(0,0,0), FXbool smoothscroll=TRUE,
+         FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
     DirPanel()
     {}
     virtual void create();
@@ -47,7 +51,7 @@ DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listfor
 		ID_DIR_COPY,
 		ID_DIR_CUT,
 		ID_DIR_COPYTO,
-		ID_DIR_MOVE,
+		ID_DIR_MOVETO,
 		ID_DIR_RENAME,
 		ID_DIR_SYMLINK,
 		ID_DIR_DELETE,
@@ -60,6 +64,8 @@ DirPanel(FXComposite *p,FXColor listbackcolor=FXRGB(255,255,255),FXColor listfor
         ID_TOGGLE_TREE,
 		ID_TITLE,
 		ID_DIRSIZE_REFRESH,
+		ID_POPUP_MENU,
+		ID_CTRL_POPUP_MENU,
 #if defined(linux)
         ID_MOUNT,
         ID_UMOUNT,
@@ -74,7 +80,8 @@ public:
 	long onClipboardRequest(FXObject*,FXSelector,void*);
 	long onCmdToggleHidden(FXObject*,FXSelector,void*);
 	long onUpdToggleHidden(FXObject* sender,FXSelector,void*);
-	long onPopupMenu(FXObject*,FXSelector,void*);
+	long onCmdPopupMenu(FXObject*,FXSelector,void*);
+	long onCmdCtrlPopupMenu(FXObject*,FXSelector,void*);
 	long onExpandTree(FXObject*,FXSelector,void*);
 	long onCollapseTree(FXObject*,FXSelector,void*);
 	long onCmdProperties(FXObject*,FXSelector,void*);
@@ -100,6 +107,7 @@ public:
 	long onUpdStatus(FXObject*,FXSelector,void*);
 	long onExpand(FXObject*,FXSelector,void*);
 	long onKeyPress(FXObject*,FXSelector,void*);
+	long onUpdDirectory(FXObject*,FXSelector,void*);
 #if defined(linux)
 	long onCmdMount(FXObject*,FXSelector,void*);
 #endif
