@@ -131,6 +131,7 @@ protected:
 	FXbool      single;                 // Allow single click navigation for directories
 	FXbool		dirsfirst;				// Sort directories first
 	FXint		deldatesize;
+	FXWindow	*focuswindow;			// Window used to test focus
 
 public:
 	StringList		*backhist;          // Back history
@@ -275,7 +276,7 @@ public:
 public:
 
     // Construct a file list
-    FileList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    FileList(FXWindow* focuswin, FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
     // Create server-side resources
     virtual void create();
@@ -375,13 +376,13 @@ public:
     void setMatchMode(FXuint mode);
 
     // Return TRUE if showing hidden files
-    FXbool showHiddenFiles() const;
+    FXbool shownHiddenFiles() const;
 
     // Show or hide hidden files
     void showHiddenFiles(FXbool showing);
 
     // Return TRUE if displaying thumbnails
-    FXbool showThumbnails() const;
+    FXbool shownThumbnails() const;
 
     // Display or not thumbnails
     void showThumbnails(FXbool display);
