@@ -1,6 +1,8 @@
 #ifndef MESSAGEBOX_H
 #define MESSAGEBOX_H
 
+#include "DialogBox.h"
+
 // Message box buttons
 enum {
 		BOX_OK                   = 0x10000000, // Message box has a only an OK button
@@ -23,7 +25,7 @@ enum {
   
   
 // Message box
-class FXAPI MessageBox : public FXDialogBox
+class FXAPI MessageBox : public DialogBox
 {
     FXDECLARE(MessageBox)
 protected:
@@ -39,7 +41,7 @@ public:
 	long onCmdSu(FXObject*,FXSelector sel,void*);
 public:
     enum {
-        ID_CLICKED_YES=FXDialogBox::ID_LAST,
+        ID_CLICKED_YES=DialogBox::ID_LAST,
         ID_CLICKED_NO,
         ID_CLICKED_OK,
         ID_CLICKED_CANCEL,
