@@ -2,7 +2,6 @@
 #define VIEWWINDOW_H
 
 #include "InputDialog.h"
-#include "FileDialog.h"
 
 
 class ViewWindow;
@@ -28,9 +27,14 @@ protected:
     FXRecentFiles       mrufiles;           // Recent files list
     FXFont              *font;              // Text window font
 	InputDialog         *printdialog;
-	FileDialog          *opendialog;
 	DialogBox			*finddialog;
 	FXTextField			*findtext;
+	FXbool				smoothscroll;
+	FXbool 				fromreg;			// Read window size and position from the regsitry
+	FXuint 				ww;			        // Window width
+	FXuint 				hh;					// Window height
+	FXuint 				xx;					// Window x position 
+	FXuint 				yy;					// Window y position
 private:
     ViewWindow()
     {}
@@ -149,6 +153,10 @@ public:
         return filenameset;
     }
 
+	void setSmoothScroll(FXbool smooth)
+	{
+		smoothscroll=smooth;
+	}
     virtual FXbool close(FXbool notify=FALSE);
     FXbool loadFile(const FXString& file);
 	void saveConfig();
