@@ -33,12 +33,11 @@ class XFileExplorer : public FXMainWindow
     FXDECLARE(XFileExplorer)
     friend class FilePanel;
     friend class DirPanel;
+    friend class DirList;
     friend class PathLinker;
 	friend class PropertiesBox;
 	friend class PreferencesBox;
 protected:
-	int rpanel_width;
-	int rpanel_tree_width;
 	enum
 	{
 		ONE_PANEL,
@@ -72,6 +71,7 @@ protected:
     FXMenuTitle		*helpmenutitle;
     Bookmarks		*bookmarks;
     FXToolBar		*generaltoolbar;
+    FXToolBar		*toolstoolbar;
     FXToolBar		*paneltoolbar;
     FXToolBar		*locationbar;
 	FXComboBox		*address;
@@ -79,16 +79,10 @@ protected:
     DirPanel		*dirpanel;
     FilePanel		*lpanel;
     FilePanel		*rpanel;
-    FXString		target;
-    FXString		sources;
-    char			*opendir;
-	FXString		xterm;
+	FXString		homelocation;
 	FXString		trashlocation;
+	FXString		startlocation;
 	FXuint			liststyle;
-	FXint			xpos;
-	FXint			ypos;
-	FXuint			width;
-	FXuint			height;
 	FXColor			listbackcolor;
 	FXColor			listforecolor;
 	FXColor			highlightcolor;
@@ -101,10 +95,16 @@ protected:
 	TextWindow*		   helpwindow;
 	FXString 		message;
 	FXuint 			panelfocus;
-	
-	
+	FXString		startdirectory;
+	FXbool			starticonic;
+	FXbool			startmaximized;
+	FXbool			smoothscroll;
+	FXdouble        twopanels_lpanel_pct;      // Panel sizes, relatively to the window width (in percent)
+	FXdouble        treepanel_tree_pct;
+	FXdouble        treetwopanels_tree_pct;
+	FXdouble        treetwopanels_lpanel_pct;
 public:
-    enum{
+	enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
 		ID_HELP,
 		ID_REFRESH,
@@ -118,7 +118,7 @@ public:
 		ID_FILE_PROPERTIES,
         ID_FILE_COPY,
         ID_FILE_RENAME,
-        ID_FILE_MOVE,
+        ID_FILE_MOVETO,
         ID_FILE_COPYTO,
         ID_FILE_CUT,
 		ID_FILE_PASTE,
@@ -137,6 +137,8 @@ public:
 		ID_SHOW_TWO_PANELS,
 		ID_SHOW_TREE_PANEL,
 		ID_SHOW_TREE_TWO_PANELS,
+		ID_SYNCHRONIZE_PANELS,
+		ID_SWITCH_PANELS,
         ID_RESTART,
         ID_NEW_WIN,
         ID_BOOKMARK,
@@ -145,7 +147,7 @@ public:
 		ID_LAST
     };
 public:
-    XFileExplorer(FXApp *app=NULL,char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
+    XFileExplorer(FXApp *app=NULL,const FXbool iconic=FALSE,const FXbool maximized=FALSE,const FXString startdir = "",const char *title = "X File Explorer",FXIcon *bigicon=NULL,FXIcon *miniicon=NULL);
     virtual void create();
     ~XFileExplorer();
     void saveConfig();
@@ -193,12 +195,16 @@ public:
 	long onCmdFileCutClp(FXObject*,FXSelector,void*);
 	long onCmdFilePasteClp(FXObject*,FXSelector,void*);
 	long onCmdFileRename(FXObject*,FXSelector,void*);
-	long onCmdFileMove(FXObject*,FXSelector,void*);
+	long onCmdFileMoveto(FXObject*,FXSelector,void*);
 	long onCmdFileCopyto(FXObject*,FXSelector,void*);
 	long onCmdFileSymlink(FXObject*,FXSelector,void*);
 	long onUpdFileMan(FXObject*,FXSelector,void*);
 	long onUpdFilePaste(FXObject*,FXSelector,void*);
 	long onCmdFileProperties(FXObject*,FXSelector,void*);
 	long onUpdFileRename(FXObject*,FXSelector,void*);
+	long onCmdSynchronizePanels(FXObject*,FXSelector,void*);
+	long onUpdSynchronizePanels(FXObject*,FXSelector,void*);
+	long onCmdSwitchPanels(FXObject*,FXSelector,void*);
+	long onUpdSwitchPanels(FXObject*,FXSelector,void*);
 };
 #endif
