@@ -2,7 +2,7 @@
 #define XFILEIMAGE_H
 
 #include "InputDialog.h"
-#include "FileDialog.h"
+#include "PathLinker.h"
 
 class XFileImage : public FXMainWindow
 {
@@ -36,7 +36,11 @@ protected:
 	FXdouble		  zoomval;				  // Actual zoom factor
 	FXbool			  fitwin;                 // Fit window when opening an image
 	InputDialog*	  printdialog;
-	FileDialog*       opendialog;
+	FXbool			  smoothscroll;
+	FXdouble		  fileheight_pct;
+	FXArrowButton     *btnbackhist;           // Back history
+	FXArrowButton     *btnforwardhist;        // Forward history
+    PathLinker*		  pathlink;
 protected:
     XFileImage()
     {}
@@ -66,7 +70,6 @@ public:
 	long onUpdToggleHidden(FXObject* sender,FXSelector sel,void* ptr);
 	long onCmdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr);
 	long onUpdToggleThumbnails(FXObject* sender,FXSelector sel,void* ptr);
-	long onUpdLabel(FXObject*,FXSelector,void*);
     long onCmdItemDoubleClicked(FXObject*,FXSelector,void*);
 	long onCmdItemClicked(FXObject* sender,FXSelector sel, void* ptr);
 	long onCmdToggleFitWin(FXObject*,FXSelector,void*);
@@ -74,11 +77,20 @@ public:
 	long onCmdPopupMenu(FXObject*,FXSelector,void*);
     long onCmdHome(FXObject*,FXSelector,void*);
     long onCmdWork(FXObject*,FXSelector,void*);
+    long onCmdDirUp(FXObject*,FXSelector,void*);
+    long onUpdDirUp(FXObject*,FXSelector,void*);
+	long onCmdDirBack(FXObject*,FXSelector,void*);
+    long onUpdDirBack(FXObject*,FXSelector,void*);
+ 	long onCmdDirForward(FXObject*,FXSelector,void*);
+    long onUpdDirForward(FXObject*,FXSelector,void*);
+	long onCmdDirBackHist(FXObject*,FXSelector,void*);
+    long onUpdDirBackHist(FXObject*,FXSelector,void*);
+ 	long onCmdDirForwardHist(FXObject*,FXSelector,void*);
+    long onUpdDirForwardHist(FXObject*,FXSelector,void*);
 public:
     enum{
         ID_ABOUT=FXMainWindow::ID_LAST,
         ID_OPEN,
-		ID_LABEL,
 		ID_TOGGLE_HIDDEN,
 		ID_TOGGLE_THUMBNAILS,
 		ID_SHOW_MINI,
@@ -103,6 +115,11 @@ public:
 		ID_TOGGLE_FIT_WIN,
         ID_HOME,
         ID_WORK,
+        ID_DIR_UP,
+		ID_DIR_BACK,
+		ID_DIR_FORWARD,
+ 		ID_DIR_BACK_HIST,
+		ID_DIR_FORWARD_HIST,
         ID_LAST
     };
 public:
@@ -112,5 +129,9 @@ public:
 	void saveConfig();
     void start(FXString starimage);
     virtual ~XFileImage();
+	void setSmoothScroll(FXbool smooth)
+	{
+		smoothscroll=smooth;
+	}
 };
 #endif
